diff src/edit.c @ 9742:0b0b9864c811 v7.4.2146

commit https://github.com/vim/vim/commit/472472898ab71ac80a86fedc37f8eb91461788dd Author: Bram Moolenaar <Bram@vim.org> Date: Tue Aug 2 22:36:02 2016 +0200 patch 7.4.2146 Problem: Not enough testing for popup menu. CTRL-E does not always work properly. Solution: Add more tests. When using CTRL-E check if the popup menu is visible. (Christian Brabandt)
author Christian Brabandt <cb@256bit.org>
date Tue, 02 Aug 2016 22:45:05 +0200
parents fd9727ae3c49
children f17ba1c9d209
line wrap: on
line diff
--- a/src/edit.c
+++ b/src/edit.c
@@ -3891,8 +3891,9 @@ ins_compl_prep(int c)
 		    && pum_visible())
 		retval = TRUE;
 
-	    /* CTRL-E means completion is Ended, go back to the typed text. */
-	    if (c == Ctrl_E)
+	    /* CTRL-E means completion is Ended, go back to the typed text.
+	     * but only do this, if the Popup is still visible */
+	    if (c == Ctrl_E && pum_visible())
 	    {
 		ins_compl_delete();
 		if (compl_leader != NULL)